@@ -46,23 +46,7 @@
 #include <goffice/cut-n-paste/foocanvas/foo-canvas-pixbuf.h>
 #include <goffice/cut-n-paste/foocanvas/foo-canvas-rect-ellipse.h>
 #include <gdk/gdkkeysyms.h>
-#include <gtk/gtknotebook.h>
-#include <gtk/gtklabel.h>
-#include <gtk/gtkbutton.h>
-#include <gtk/gtkentry.h>
-#include <gtk/gtktreeselection.h>
-#include <gtk/gtktreeview.h>
-#include <gtk/gtktreestore.h>
-#include <gtk/gtkimage.h>
-#include <gtk/gtkimagemenuitem.h>
-#include <gtk/gtkframe.h>
-#include <gtk/gtkviewport.h>
-#include <gtk/gtkvbox.h>
-#include <gtk/gtkhbox.h>
-#include <gtk/gtkcellrenderertext.h>
-#include <gtk/gtkcellrendererpixbuf.h>
-#include <gtk/gtkstock.h>
-#include <gtk/gtkliststore.h>
+#include <gtk/gtk.h>
 #include <string.h>
 
 typedef struct _GraphGuruState		GraphGuruState;
@@ -189,7 +173,7 @@ graph_typeselect_minor (GraphGuruTypeSelector *typesel, FooCanvasItem *item)
 	gboolean enable_next_button;
 	GogPlot *plot;
 
-	if (typesel->current_minor_item == item)
+	if (typesel->current_minor_item == item || typesel->sample_graph_item == item)
 		return;
 
 	type = g_object_get_data (G_OBJECT (item), PLOT_TYPE_KEY);
@@ -1142,6 +1126,7 @@ graph_guru_type_selector_new (GraphGuruState *s)
 	typesel->current_type = NULL;
 	typesel->sample_graph_item = NULL;
 	typesel->max_priority_so_far = -1;
+	s->type_selector = typesel;
 
 	selector = glade_xml_get_widget (gui, "type_selector");
 
@@ -1339,3 +1324,15 @@ gog_guru (GogGraph *graph, GogDataAllocator *dalloc,
 
 	return state->dialog;
 }
+
+void
+gog_guru_add_custom_widget (GtkWidget *guru, GtkWidget *custom)
+{
+	GraphGuruState *state = g_object_get_data (G_OBJECT (guru), "state");
+	GtkBox *box = GTK_BOX (gtk_widget_get_parent (gtk_widget_get_parent (state->type_selector->canvas)));
+	if (custom) {
+		gtk_box_pack_start (GTK_BOX (box), custom, FALSE, TRUE, 0);
+		g_object_set_data (G_OBJECT (custom), "graph", state->graph);
+		gtk_widget_show_all (custom);
+	}
+}
