@@ -29,10 +29,8 @@
 #include <glib-object.h>
 
 #include <gsf/gsf.h>
-#include <libart_lgpl/libart.h>
 
 #ifdef GOFFICE_WITH_GTK
-#include <gtk/gtkenums.h>
 #include <goffice/gtk/goffice-gtk.h>
 #include <gdk/gdk.h>
 #else
@@ -59,6 +57,10 @@ typedef enum
 } GtkAnchorType;
 #endif
 
+#ifdef GOFFICE_WITH_GMATHML
+#include <gmathmlview.h>
+#endif
+
 #include <cairo.h>
 #ifdef CAIRO_HAS_SVG_SURFACE
 #define GOG_RENDERER_CAIRO_WITH_SVG
@@ -101,6 +103,10 @@ void  gog_renderer_draw_shape 		(GogRenderer *renderer, GOPath const *path);
 void  gog_renderer_stroke_shape		(GogRenderer *renderer, GOPath const *path);
 void  gog_renderer_fill_shape 		(GogRenderer *renderer, GOPath const *path);
 
+void  gog_renderer_draw_circle		(GogRenderer *rend, double x, double y, double r);
+void  gog_renderer_stroke_circle 	(GogRenderer *rend, double x, double y, double r);
+void  gog_renderer_fill_circle	 	(GogRenderer *rend, double x, double y, double r);
+
 void  gog_renderer_draw_rectangle	(GogRenderer *rend, GogViewAllocation const *rect);
 void  gog_renderer_stroke_rectangle 	(GogRenderer *rend, GogViewAllocation const *rect);
 void  gog_renderer_fill_rectangle 	(GogRenderer *rend, GogViewAllocation const *rect);
@@ -146,13 +152,10 @@ gboolean 	 gog_renderer_export_image 	(GogRenderer *renderer, GOImageFormat form
 
 GogRenderer 	*gog_renderer_new 		(GogGraph *graph);
 
-/* Deprecated API */
-void  		gog_renderer_draw_sharp_path	(GogRenderer *rend, ArtVpath *path);
-void  		gog_renderer_draw_sharp_polygon (GogRenderer *rend, ArtVpath *path, gboolean narrow);
-
-void  		gog_renderer_draw_path      	(GogRenderer *rend, ArtVpath const *path);
-void  		gog_renderer_draw_polygon   	(GogRenderer *rend, ArtVpath const *path, gboolean narrow);
-void  		gog_renderer_draw_bezier_path   (GogRenderer *rend, ArtBpath const *path);
+#ifdef GOFFICE_WITH_GMATHML
+void		 gog_renderer_draw_equation	(GogRenderer *renderer, GMathmlView *mathml_view,
+						 double x, double y);
+#endif
 
 G_END_DECLS
 
