@@ -29,7 +29,6 @@
 #include <goffice/utils/go-marshalers.h>
 #include <goffice/gtk/goffice-gtk.h>
 
-#include <gtk/gtk.h>
 #include <gdk/gdkkeysyms.h>
 #include <glib/gi18n-lib.h>
 
@@ -180,6 +179,7 @@ static void
 go_combo_box_popup_hide_unconditional (GOComboBox *combo_box)
 {
 	gboolean popup_info_destroyed = FALSE;
+	GObject *pdc;
 
 	g_return_if_fail (combo_box != NULL);
 	g_return_if_fail (IS_GO_COMBO_BOX (combo_box));
@@ -197,10 +197,10 @@ go_combo_box_popup_hide_unconditional (GOComboBox *combo_box)
 	gdk_display_pointer_ungrab (gtk_widget_get_display (combo_box->priv->toplevel),
 				    GDK_CURRENT_TIME);
 
-	g_object_ref (combo_box->priv->popdown_container);
+	pdc = g_object_ref (combo_box->priv->popdown_container);
 	g_signal_emit (combo_box,
 		       go_combo_box_signals [POP_DOWN_DONE], 0,
-		       combo_box->priv->popdown_container, &popup_info_destroyed);
+		       pdc, &popup_info_destroyed);
 
 	if (popup_info_destroyed){
 		gtk_container_remove (
@@ -208,7 +208,7 @@ go_combo_box_popup_hide_unconditional (GOComboBox *combo_box)
 			combo_box->priv->popdown_container);
 		combo_box->priv->popdown_container = NULL;
 	}
-	g_object_unref (combo_box->priv->popdown_container);
+	g_object_unref (pdc);
 	set_arrow_state (combo_box, FALSE);
 }
 
@@ -245,6 +245,21 @@ go_combo_box_style_set (GtkWidget *widget,
 	go_combo_box_set_tearable (GO_COMBO_BOX (widget), add_tearoffs);
 }
 
+static void
+go_combo_box_realize (GtkWidget *widget)
+{
+	GOComboBox *combo = (GOComboBox *)widget;
+	GdkCursor *cursor;
+
+	cursor = gdk_cursor_new_for_display (gtk_widget_get_display (widget),
+					     GDK_TOP_LEFT_ARROW);
+	gtk_widget_realize (combo->priv->popup);
+	gdk_window_set_cursor (combo->priv->popup->window, cursor);
+	gdk_cursor_unref (cursor);
+
+	((GtkWidgetClass *)go_combo_box_parent_class)->realize (widget);
+}
+
 static void
 go_combo_box_class_init (GObjectClass *object_class)
 {
@@ -253,6 +268,7 @@ go_combo_box_class_init (GObjectClass *object_class)
 
 	object_class->finalize = go_combo_box_finalize;
 	widget_class->mnemonic_activate = go_combo_box_mnemonic_activate;
+	widget_class->realize = go_combo_box_realize;
 	((GtkObjectClass *)object_class)->destroy = go_combo_box_destroy;
 
 	gtk_widget_class_install_style_property
@@ -518,7 +534,6 @@ static void
 go_combo_box_init (GOComboBox *combo_box)
 {
 	GtkWidget *arrow;
-	GdkCursor *cursor;
 
 	combo_box->priv = g_new0 (GOComboBoxPrivate, 1);
 	combo_box->priv->updating_buttons = FALSE;
@@ -546,27 +561,18 @@ go_combo_box_init (GOComboBox *combo_box)
 	 */
 
 	combo_box->priv->toplevel = gtk_window_new (GTK_WINDOW_POPUP);
-#if GLIB_CHECK_VERSION(2,10,0) && GTK_CHECK_VERSION(2,8,14)
-	g_object_ref_sink (combo_box->priv->toplevel);
-#else
 	g_object_ref (combo_box->priv->toplevel);
-	gtk_object_sink (GTK_OBJECT (combo_box->priv->toplevel));
-#endif
 	g_object_set (G_OBJECT (combo_box->priv->toplevel),
-		"allow-shrink",	FALSE,
-		"allow-grow",	TRUE,
-		NULL);
+		      "allow-shrink", FALSE,
+		      "allow-grow", TRUE,
+		      "type-hint", GDK_WINDOW_TYPE_HINT_COMBO,
+		      NULL);
 
 	combo_box->priv->popup = gtk_event_box_new ();
 	gtk_container_add (GTK_CONTAINER (combo_box->priv->toplevel),
 			   combo_box->priv->popup);
 	gtk_widget_show (combo_box->priv->popup);
 
-	gtk_widget_realize (combo_box->priv->popup);
-	cursor = gdk_cursor_new_for_display (gtk_widget_get_display (GTK_WIDGET (combo_box)), GDK_TOP_LEFT_ARROW);
-	gdk_window_set_cursor (combo_box->priv->popup->window, cursor);
-	gdk_cursor_unref (cursor);
-
 	combo_box->priv->torn_off = FALSE;
 	combo_box->priv->tearoff_window = NULL;
 
