@@ -30,7 +30,6 @@
 #include "goffice/utils/go-marshalers.h"
 #include "goffice/utils/go-glib-extras.h"
 
-#include <gtk/gtk.h>
 #include <gsf/gsf-impl-utils.h>
 #include <glib/gi18n-lib.h>
 
@@ -521,18 +520,28 @@ static void
 fmt_dialog_init_fmt_list (GOFormatSel *gfs, char const *const *formats,
 			  GtkTreeIter *select)
 {
-	GtkTreeIter iter;
-	char *fmt;
-	const char *cur_fmt = go_format_as_XL (gfs->format.spec);
+	GOFormatMagic cur_magic = go_format_get_magic (gfs->format.spec);
 
 	for (; *formats; formats++) {
+		GtkTreeIter iter;
+		char *fmt = go_format_str_localize (*formats);
+		GOFormat *f = go_format_new_from_XL (*formats);
+		GOFormatMagic magic = go_format_get_magic (f);
+		gboolean found;
+
 		gtk_list_store_append (gfs->format.formats.model, &iter);
-		fmt = go_format_str_localize (*formats);
 		gtk_list_store_set (gfs->format.formats.model, &iter,
 				    0, fmt, -1);
 		g_free (fmt);
 
-		if (!strcmp (*formats, cur_fmt))
+		/* Magic formats are fully defined by their magic.  */
+		found = cur_magic
+			? (cur_magic == magic)
+			: go_format_eq (f, gfs->format.spec);
+
+		go_format_unref (f);
+
+		if (found)
 			*select = iter;
 	}
 }
@@ -744,9 +753,10 @@ stays:
 				format_entry_set_text (gfs, tmp);
 				g_free (tmp);
 			} else if (select.stamp == 0)
-				gtk_tree_model_get_iter_first (
+				if (!gtk_tree_model_get_iter_first (
 					GTK_TREE_MODEL (gfs->format.formats.model),
-					&select);
+					&select))
+					break;
 
 			if (select.stamp != 0) {
 				GtkTreePath *path = gtk_tree_model_get_path (
@@ -855,6 +865,8 @@ cb_format_entry_changed (GtkEditable *w, GOFormatSel *gfs)
 		return;
 
 	fmt = go_format_str_delocalize (gtk_entry_get_text (GTK_ENTRY (w)));
+	if (!fmt)
+		fmt = g_strdup ("*");
 	cur_fmt = go_format_as_XL (gfs->format.spec);
 
 	if (strcmp (cur_fmt, fmt)) {
