@@ -23,13 +23,13 @@
 
 #include <goffice/goffice-config.h>
 #include <goffice/ms-compat/go-ms-parser.h>
-#include <glib/gmacros.h>
+#include <glib.h>
 #include <gsf/gsf-input.h>
 #include <gsf/gsf-utils.h>
 
 #define d(x) x
 
-#define CVS_VERSION "$Id$"
+#define CVS_VERSION "$Id: go-ms-parser.c 2295 2008-12-14 21:58:11Z mortenw $"
 #define ERROR_STRING(cond,str) G_STRLOC "\n<" CVS_VERSION ">\n" str " (" #cond ")"
 #define ERROR(cond,str) { \
 	if (!(cond)) { \
