@@ -51,6 +51,17 @@ typedef enum {
 	GO_FORMAT_MARKUP	= 11	/* Internal use only */
 } GOFormatFamily;
 
+typedef enum {
+	GO_FORMAT_MAGIC_NONE            = 0,
+	GO_FORMAT_MAGIC_LONG_DATE       = 0xf800,    /* Official */
+	GO_FORMAT_MAGIC_MEDIUM_DATE     = 0xf8f1,
+	GO_FORMAT_MAGIC_SHORT_DATE      = 0xf8f2,
+	GO_FORMAT_MAGIC_SHORT_DATETIME  = 0xf8fa,
+	GO_FORMAT_MAGIC_LONG_TIME       = 0xf400,    /* Official */
+	GO_FORMAT_MAGIC_MEDIUM_TIME     = 0xf4f1,
+	GO_FORMAT_MAGIC_SHORT_TIME      = 0xf4f2
+} GOFormatMagic;
+
 typedef enum {
 	GO_FORMAT_NUMBER_OK = 0,
 	GO_FORMAT_NUMBER_INVALID_FORMAT,
@@ -92,6 +103,7 @@ GOFormat *go_format_default_time	(void);
 GOFormat *go_format_default_date_time	(void);
 GOFormat *go_format_default_percentage	(void);
 GOFormat *go_format_default_money	(void);
+GOFormat *go_format_default_accounting  (void);
 
 char     *go_format_str_localize        (char const *str);
 char	 *go_format_str_delocalize	(char const *str);
@@ -100,6 +112,7 @@ const char* go_format_as_XL	   	(GOFormat const *fmt);
 GOFormat *go_format_ref		 	(GOFormat *fmt);
 void      go_format_unref		(GOFormat *fmt);
 
+gboolean  go_format_is_invalid          (GOFormat const *fmt);
 gboolean  go_format_is_general          (GOFormat const *fmt);
 gboolean  go_format_is_markup           (GOFormat const *fmt);
 gboolean  go_format_is_text             (GOFormat const *fmt);
@@ -109,6 +122,9 @@ int       go_format_is_date             (GOFormat const *fmt);
 int       go_format_month_before_day    (GOFormat const *fmt);
 gboolean  go_format_has_hour            (GOFormat const *fmt);
 
+GOFormatMagic go_format_get_magic       (GOFormat const *fmt);
+GOFormat *go_format_new_magic           (GOFormatMagic m);
+
 const GOFormat *go_format_specialize          (GOFormat const *fmt,
 					       double val, char type,
 					       gboolean *inhibit_minus);
