@@ -28,7 +28,8 @@
 #include "gog-power-reg.h"
 #include <goffice/data/go-data.h>
 #include <goffice/graph/gog-series-impl.h>
-#include <goffice/utils/go-math.h>
+#include <goffice/math/go-math.h>
+#include <goffice/utils/go-persist.h>
 #include <glib/gi18n-lib.h>
 
 #include <gsf/gsf-impl-utils.h>
@@ -53,12 +54,13 @@ gog_lin_reg_curve_update (GogObject *obj)
 	double const *y_vals, *x_vals = NULL;
 	int used, nb;
 
-	g_return_if_fail (gog_series_is_valid (series));
+	if (!gog_series_is_valid (series))
+		return;
 
 	nb = gog_series_get_xy_data (series, &x_vals, &y_vals);
 	used = (GOG_LIN_REG_CURVE_GET_CLASS(rc))->build_values (rc, x_vals, y_vals, nb);
 	if (used > 1) {
-		regression_stat_t *stats = go_regression_stat_new ();
+		go_regression_stat_t *stats = go_regression_stat_new ();
 		RegressionResult res =
 			(GOG_LIN_REG_CURVE_GET_CLASS(rc))->lin_reg_func (rc->x_vals, rc->dims,
 						rc->y_vals, used, rc->affine, rc->base.a, stats);
@@ -136,10 +138,9 @@ gog_lin_reg_curve_build_values (GogLinRegCurve *rc, double const *x_vals, double
 }
 
 #ifdef GOFFICE_WITH_GTK
-#include <gtk/gtktable.h>
-#include <gtk/gtkcheckbutton.h>
-#include <gtk/gtktogglebutton.h>
-#include <gtk/gtktooltips.h>
+#include <gtk/gtk.h>
+#include <goffice/gtk/goffice-gtk.h>
+
 static void
 affine_toggled_cb (GtkToggleButton *btn, GObject *obj)
 {
@@ -152,13 +153,11 @@ gog_lin_reg_curve_populate_editor (GogRegCurve *reg_curve, gpointer table)
 	int rows, columns;
 	GtkWidget *w;
 	GogLinRegCurve *lin = GOG_LIN_REG_CURVE (reg_curve);
-	GtkTooltips *tips = gtk_tooltips_new ();
 
 	g_object_get (G_OBJECT (table), "n-rows", &rows, "n-columns", &columns, NULL);
 	gtk_table_resize (table, rows + 1, columns);
 	w = gtk_check_button_new_with_label (_("Affine"));
-	gtk_tooltips_set_tip (GTK_TOOLTIPS (tips), w,
-					_("Uncheck to force zero intercept"), NULL);
+	go_widget_set_tooltip_text (w, _("Uncheck to force zero intercept"));
 	gtk_widget_show (w);
 	gtk_table_attach (table, w, 0, columns, rows, rows + 1, GTK_FILL | GTK_EXPAND, 0, 0, 0);
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (w), lin->affine);
@@ -266,13 +265,13 @@ gog_lin_reg_curve_class_init (GogRegCurveClass *reg_curve_klass)
 			_("Affine"),
 			_("If true, a non-zero constant is allowed"),
 			TRUE, 
-			GSF_PARAM_STATIC | G_PARAM_READWRITE | GOG_PARAM_PERSISTENT));
+			GSF_PARAM_STATIC | G_PARAM_READWRITE | GO_PARAM_PERSISTENT));
 	g_object_class_install_property (gobject_klass, REG_LIN_REG_CURVE_PROP_DIMS,
 		g_param_spec_uint ("dims", 
 			_("Dims"),
 			_("Number of x-vectors"),
 		       	1, 10, 1, 
-			GSF_PARAM_STATIC | G_PARAM_READWRITE|GOG_PARAM_PERSISTENT));
+			GSF_PARAM_STATIC | G_PARAM_READWRITE|GO_PARAM_PERSISTENT));
 }
 
 static void
