@@ -24,8 +24,9 @@
 #include <goffice/app/go-plugin.h>
 #include <goffice/data/go-data.h>
 #include <goffice/graph/gog-data-allocator.h>
-#include <goffice/utils/go-math.h>
-#include <goffice/utils/go-rangefunc.h>
+#include <goffice/math/go-math.h>
+#include <goffice/math/go-rangefunc.h>
+#include <goffice/utils/go-persist.h>
 #include <gsf/gsf-impl-utils.h>
 #include <glib/gi18n-lib.h>
 
@@ -38,9 +39,8 @@ static GObjectClass *exp_smooth_parent_klass;
 
 #ifdef GOFFICE_WITH_GTK
 #include <goffice/gtk/goffice-gtk.h>
-#include <gtk/gtkeventbox.h>
-#include <gtk/gtkspinbutton.h>
-#include <gtk/gtktable.h>
+#include <gtk/gtk.h>
+
 static void
 steps_changed_cb (GtkSpinButton *button, GObject *es)
 {
@@ -59,12 +59,10 @@ gog_exp_smooth_populate_editor (GogObject *obj,
 		go_plugins_get_plugin_by_id ("GOffice_smoothing"));
 	char	 *path = g_build_filename (dir, "gog-exp-smooth.glade", NULL);
 	GladeXML *gui = go_libglade_new (path, "exp-smooth-prefs", GETTEXT_PACKAGE, cc);
-	GtkTooltips *tips = gtk_tooltips_new ();
 	GtkWidget *label, *box, *w = glade_xml_get_widget (gui, "steps");
 	GtkTable *table;
 
-	gtk_tooltips_set_tip (GTK_TOOLTIPS (tips), w,
-					_("Number of interpolation steps"), NULL);
+	go_widget_set_tooltip_text (w, _("Number of interpolation steps"));
 	gtk_spin_button_set_range (GTK_SPIN_BUTTON (w), 10, G_MAXINT);
 	gtk_spin_button_set_value (GTK_SPIN_BUTTON (w), es->steps);
 	g_signal_connect (G_OBJECT (w), "value-changed", G_CALLBACK (steps_changed_cb), obj);
@@ -72,10 +70,9 @@ gog_exp_smooth_populate_editor (GogObject *obj,
 	w = GTK_WIDGET (gog_data_allocator_editor (dalloc, set, 0, GOG_DATA_SCALAR));
 	box = gtk_event_box_new ();
 	gtk_container_add (GTK_CONTAINER (box), w);
-	gtk_tooltips_set_tip (GTK_TOOLTIPS (tips), box,
-					_("Default period is 10 * (xmax - xmin)/(nvalues - 1)\n"
+	go_widget_set_tooltip_text (box, _("Default period is 10 * (xmax - xmin)/(nvalues - 1)\n"
 					"If no value or a negative (or nul) value is provided, the "
-					"default will be used"), NULL);
+					"default will be used"));
 	gtk_widget_show_all (box);
 	gtk_table_attach (table, box, 1, 2, 0, 1, GTK_FILL | GTK_EXPAND, 0, 0, 0);
 	label = glade_xml_get_widget (gui, "period-lbl");
@@ -99,14 +96,10 @@ gog_exp_smooth_update (GogObject *obj)
 	double *x, *y, *w, *incr;
 	double epsilon;
 
-	if (es->base.x != NULL) {
-		g_free (es->base.x);
-		es->base.x = NULL;
-	}
-	if (es->base.y != NULL) {
-		g_free (es->base.y);
-		es->base.y = NULL;
-	}
+	g_free (es->base.x);
+	es->base.x = NULL;
+	g_free (es->base.y);
+	es->base.y = NULL;
 	if (!gog_series_is_valid (series))
 		return;
 
@@ -236,9 +229,11 @@ gog_exp_smooth_class_init (GogSmoothedCurveClass *curve_klass)
 	gog_object_klass->type_name	= gog_exp_smooth_type_name;
 
 	g_object_class_install_property (gobject_klass, EXP_SMOOTH_PROP_STEPS,
-		g_param_spec_int ("steps", "steps",
-			"Number of interpolation steps", 10, G_MAXINT, 100,
-			G_PARAM_READWRITE|GOG_PARAM_PERSISTENT));
+		g_param_spec_int ("steps", 
+			_("Steps"),
+			_("Number of interpolation steps"), 
+			10, G_MAXINT, 100,
+			GSF_PARAM_STATIC | G_PARAM_READWRITE | GO_PARAM_PERSISTENT));
 }
 
 static void
@@ -274,7 +269,7 @@ gog_exp_smooth_dataset_init (GogDatasetClass *iface)
 {
 	iface->get_elem	   = gog_exp_smooth_dataset_get_elem;
 	iface->dims	   = gog_exp_smooth_dataset_dims;
-	iface->dim_changed	   = gog_exp_smooth_dataset_dim_changed;
+	iface->dim_changed = gog_exp_smooth_dataset_dim_changed;
 }
 
 GSF_DYNAMIC_CLASS_FULL (GogExpSmooth, gog_exp_smooth,
